# SPDX-FileCopyrightText: 2024-present ZanSara <github@zansara.dev>
# SPDX-License-Identifier: AGPL-3.0-or-later
"""
Init file for `intentional_terminal`.
"""

from intentional_terminal.bot_interface import TerminalBotInterface

__all__ = ["TerminalBotInterface"]
